@@ -5,10 +5,10 @@
 #![feature(member_annotations)]
 
 __author__ = 'Niklas Rosenstein <rosensteinniklas@gmail.com>'
-__version__ = '0.3.0'
+__version__ = '0.4.2'
 
 from ._converter import *
 from ._datamodel import *
 from ._locator import Locator
-from ._typing import *
 from ._union import *
+from .utils import type_repr
